#include "mesh_processing.h"
#include <QGenericMatrix>
#include <unordered_set>


std::vector<HalfedgeHandle> findBorders(MyMesh &mesh) {
	std::vector<HalfedgeHandle> borders;
	std::set<HalfedgeHandle> ignore;
	for (HalfedgeHandle it : mesh.halfedges()) {
		if (mesh.is_boundary(it)
			&& ignore.find(it) == ignore.end()) {
			borders.push_back(it);
			ignore.insert(it);
			for (HalfedgeHandle it2 : HalfedgeLoopRange(mesh, it)) {
				ignore.insert(it2);
			}
		}
	}
	return borders;
}


void setBorderColor(MyMesh &mesh, const HalfedgeHandle &border,
					MyMesh::Color color) {
	for (HalfedgeHandle it : HalfedgeLoopRange(mesh, border)) {
		mesh.set_color(mesh.to_vertex_handle(it), color);
	}
}


void fillHoleDumb(MyMesh &mesh, HalfedgeHandle &border) {
	mesh.request_vertex_status();
	mesh.request_edge_status();
	mesh.request_face_status();

	Point center(0, 0, 0);
	size_t length = 0;
	for (HalfedgeHandle it : HalfedgeLoopRange(mesh, border)) {
		VertexHandle vert = mesh.to_vertex_handle(it);
		center += mesh.point(vert);
		length++;
	}
	center /= length;
	VertexHandle center_handle = mesh.new_vertex_dirty(center);

	for (HalfedgeHandle it = border;
		 mesh.to_vertex_handle(it) != center_handle;) {
		HalfedgeHandle next = mesh.next_halfedge_handle(it);
		mesh.add_face(mesh.from_vertex_handle(it),
					  mesh.to_vertex_handle(it),
					  center_handle);
		it = next;
	}
}
